Encoder

Struct Encoder 

pub struct Encoder<W> { /* private fields */ }
An encoder for encoding lilliput values.

Implementations

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_bool(&mut self, value: bool) -> Result<()>

Encodes a boolean value.

pub fn encode_bool_value(&mut self, value: &BoolValue) -> Result<()>

Encodes a boolean value, from a BoolValue.

pub fn encode_bool_header(&mut self, header: &BoolHeader) -> Result<()>

Encodes a boolean value’s header.

pub fn header_for_bool(&self, value: bool) -> BoolHeader

Creates a header for value.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_bytes(&mut self, value: &[u8]) -> Result<()>

Encodes a byte array value, from a slice reference.

pub fn encode_bytes_value(&mut self, value: &BytesValue) -> Result<()>

Encodes a byte array value, from a BytesValue.

pub fn encode_bytes_header(&mut self, header: &BytesHeader) -> Result<()>

Encodes a byte array value’s header.

pub fn header_for_bytes_len(&self, len: usize) -> BytesHeader

Creates a header for a byte array value, from its length.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_f32(&mut self, value: f32) -> Result<()>

Encodes a 32-bit floating-point value.

pub fn encode_f64(&mut self, value: f64) -> Result<()>

Encodes a 64-bit floating-point value.

pub fn encode_float_value(&mut self, value: &FloatValue) -> Result<()>

Encodes a floating-point value, from a FloatValue.

pub fn encode_float_header(&mut self, header: &FloatHeader) -> Result<()>

Encodes a floating-point value’s header.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_i8(&mut self, value: i8) -> Result<()>

Encodes a 8-bit signed integer value.

pub fn encode_i16(&mut self, value: i16) -> Result<()>

Encodes a 16-bit signed integer value.

pub fn encode_i32(&mut self, value: i32) -> Result<()>

Encodes a 32-bit signed integer value.

pub fn encode_i64(&mut self, value: i64) -> Result<()>

Encodes a 64-bit signed integer value.

pub fn encode_u8(&mut self, value: u8) -> Result<()>

Encodes a 8-bit unsigned integer value.

pub fn encode_u16(&mut self, value: u16) -> Result<()>

Encodes a 16-bit unsigned integer value.

pub fn encode_u32(&mut self, value: u32) -> Result<()>

Encodes a 32-bit unsigned integer value.

pub fn encode_u64(&mut self, value: u64) -> Result<()>

Encodes a 64-bit unsigned integer value.

pub fn encode_signed_int_value(&mut self, value: &SignedIntValue) -> Result<()>

Encodes a signed integer value, from a SignedIntValue.

pub fn encode_unsigned_int_value( &mut self, value: &UnsignedIntValue, ) -> Result<()>

Encodes an unsigned integer value, from a UnsignedIntValue.

pub fn encode_int_value(&mut self, value: &IntValue) -> Result<()>

Encodes an integer value, from a IntValue.

pub fn encode_int_header(&mut self, header: &IntHeader) -> Result<()>

Encodes a integer value’s header.

pub fn header_for_signed_int<T>(&self, value: T) -> IntHeader
where T: Signed + WithPackedBeBytes,

Creates a header for a signed integer value.

pub fn header_for_unsigned_int<T>(&self, value: T) -> IntHeader
where T: Unsigned + WithPackedBeBytes,

Creates a header for an unsigned integer value.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_map(&mut self, value: &Map) -> Result<()>

Encodes a map value.

pub fn encode_map_value(&mut self, value: &MapValue) -> Result<()>

Encodes a map value, from a MapValue.

pub fn encode_map_header(&mut self, header: &MapHeader) -> Result<()>

Encodes a map value’s header.

pub fn header_for_map_len(&self, len: usize) -> MapHeader

Creates a header for a map value, from its length.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_null(&mut self) -> Result<()>

Encodes a null value.

pub fn encode_null_value(&mut self, value: &NullValue) -> Result<()>

Encodes a null value, as a NullValue.

pub fn encode_null_header(&mut self, header: &NullHeader) -> Result<()>

Encodes a null value’s header.

pub fn header_for_null(&self) -> NullHeader

Creates a header for a null value.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_seq(&mut self, value: &[Value]) -> Result<()>

Encodes a sequence value.

pub fn encode_seq_value(&mut self, value: &SeqValue) -> Result<()>

Encodes a sequence value, from a SeqValue.

pub fn encode_seq_header(&mut self, header: &SeqHeader) -> Result<()>

Encodes a sequence value’s header.

pub fn header_for_seq_len(&self, len: usize) -> SeqHeader

Creates a header for a sequence value, from its length.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_str(&mut self, value: &str) -> Result<()>

Encodes a string value, from a reference.

pub fn encode_string_value(&mut self, value: &StringValue) -> Result<()>

Encodes a string value, from a StringValue.

pub fn encode_string_header(&mut self, header: &StringHeader) -> Result<()>

Enodes a string value’s header.

pub fn header_for_str_len(&self, len: usize) -> StringHeader

Creates a header for a string value, from its length.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_unit(&mut self) -> Result<()>

Encodes a unit value.

pub fn encode_unit_value(&mut self, value: &UnitValue) -> Result<()>

Encodes a unit value, from a UnitValue.

pub fn encode_unit_header(&mut self, header: &UnitHeader) -> Result<()>

Encodes a unit value’s header.

pub fn header_for_unit(&self) -> UnitHeader

Creates a header for a unit value.

Source

impl<W> Encoder<W>

pub fn from_writer(writer: W) -> Self

Creates a encoder from writer.

pub fn new(writer: W, config: EncoderConfig) -> Self

Creates a encoder from writer, configured by config.

pub fn into_writer(self) -> W

Returns the encoder’s internal writer, consuming self.

pub fn pos(&self) -> usize

Returns the encoder’s current write position.

Source

impl<W> Encoder<W>
where W: Write,

pub fn encode_header(&mut self, header: &Header) -> Result<()>

Encodes a value’s Header.

pub fn encode_value(&mut self, value: &Value) -> Result<()>

Encodes a Value.