#[repr(u8)]pub enum ErrorCode {
UnexpectedEndOfFile = 1,
InvalidType = 11,
InvalidValue = 21,
InvalidLength = 31,
UnknownLength = 41,
NumberOutOfRange = 51,
Uncategorized = 61,
DepthLimitExceeded = 71,
Utf8 = 81,
ReservedType = 91,
StdIo = 255,
}Expand description
This type represents all possible errors that can occur when serializing or deserializing Lilliput data.
Variants
UnexpectedEndOfFile = 1
Unexpected EOF while parsing.
InvalidType = 11
A mismatch occurred between the decoded and expected value types.
InvalidValue = 21
The enclosed I/O error occurred while trying to read the encoded MessagePack data.
InvalidLength = 31
A decoded sequence/map did not have the enclosed expected length.
UnknownLength = 41
An encoded sequence/map did not provide a length.
NumberOutOfRange = 51
A numeric cast failed due to an out-of-range error.
Uncategorized = 61
An otherwise uncategorized error occurred.
DepthLimitExceeded = 71
The depth limit was exceeded.
Utf8 = 81
An encoded string could not be parsed as UTF-8.
ReservedType = 91
Reserved type
StdIo = 255
std::io::Error.