pub struct Error { /* private fields */ }Expand description
A minimal representation of all possible errors that can occur.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn end_of_file() -> Self
pub fn end_of_file() -> Self
EOF while parsing.
Sourcepub fn invalid_type(
unexpected: String,
expected: String,
pos: Option<usize>,
) -> Self
pub fn invalid_type( unexpected: String, expected: String, pos: Option<usize>, ) -> Self
A mismatch occurred between the decoded and expected value types.
Sourcepub fn invalid_value(
unexpected: String,
expected: String,
pos: Option<usize>,
) -> Self
pub fn invalid_value( unexpected: String, expected: String, pos: Option<usize>, ) -> Self
The enclosed I/O error occurred while trying to read the encoded MessagePack data.
Sourcepub fn invalid_length(
unexpected: String,
expected: String,
pos: Option<usize>,
) -> Self
pub fn invalid_length( unexpected: String, expected: String, pos: Option<usize>, ) -> Self
A decoded sequence/map did not have the enclosed expected length.
Sourcepub fn unknown_length() -> Self
pub fn unknown_length() -> Self
An encoded sequence/map did not provide a length.
Sourcepub fn number_out_of_range(pos: Option<usize>) -> Self
pub fn number_out_of_range(pos: Option<usize>) -> Self
A numeric cast failed due to an out-of-range error.
Sourcepub fn uncategorized(msg: impl Display, pos: Option<usize>) -> Self
pub fn uncategorized(msg: impl Display, pos: Option<usize>) -> Self
An otherwise uncategorized error occurred.
Sourcepub fn depth_limit_exceeded(pos: Option<usize>) -> Self
pub fn depth_limit_exceeded(pos: Option<usize>) -> Self
The depth limit was exceeded.
Sourcepub fn utf8(err: Utf8Error, pos: Option<usize>) -> Self
pub fn utf8(err: Utf8Error, pos: Option<usize>) -> Self
An encoded string could not be parsed as UTF-8.
Sourcepub fn reserved_type() -> Self
pub fn reserved_type() -> Self
Reserved type.