pub enum IntValue {
Signed(SignedIntValue),
Unsigned(UnsignedIntValue),
}Expand description
Represents an integer number.
Variants
Implementations
Sourceimpl IntValue
impl IntValue
Sourcepub fn to_signed(self) -> Result<SignedIntValue, TryFromIntError>
pub fn to_signed(self) -> Result<SignedIntValue, TryFromIntError>
Attempts to convert the value into a signed value.
Sourcepub fn to_unsigned(self) -> Result<UnsignedIntValue, TryFromIntError>
pub fn to_unsigned(self) -> Result<UnsignedIntValue, TryFromIntError>
Attempts to convert the value into an unsigned value.