pub enum Value {
Int(IntValue),
String(StringValue),
Seq(SeqValue),
Map(MapValue),
Float(FloatValue),
Bytes(BytesValue),
Bool(BoolValue),
Unit(UnitValue),
Null(NullValue),
}Expand description
Represents a value.
Variants
Int(IntValue)
Represents a integer number.
String(StringValue)
Represents a string.
Seq(SeqValue)
Represents a sequence of values.
Map(MapValue)
Represents a map of key-value pairs.
By default the map is backed by a BTreeMap. Enable the preserve_order
feature of serde_lilliput to use OrderMap instead, which preserves
entries in the order they are inserted into the map.
Float(FloatValue)
Represents a floating-point number.
Bytes(BytesValue)
Represents a byte array.
Bool(BoolValue)
Represents a boolean.
Unit(UnitValue)
Represents a unit value.
Null(NullValue)
Represents a null value.