pub enum Header {
Int(IntHeader),
String(StringHeader),
Seq(SeqHeader),
Map(MapHeader),
Float(FloatHeader),
Bytes(BytesHeader),
Bool(BoolHeader),
Unit(UnitHeader),
Null(NullHeader),
}Expand description
A value’s header.
Variants
Int(IntHeader)
Represents a integer number.
String(StringHeader)
Represents a string.
Seq(SeqHeader)
Represents a sequence of values.
Map(MapHeader)
Represents a map of key-value pairs.
By default the map is backed by a BTreeMap. Enable the preserve_order
feature of serde_lilliput to use OrderMap instead, which preserves
entries in the order they are inserted into the map.
Float(FloatHeader)
Represents a floating-point number.
Bytes(BytesHeader)
Represents a byte array.
Bool(BoolHeader)
Represents a boolean.
Unit(UnitHeader)
Represents a unit value.
Null(NullHeader)
Represents a null value.
Implementations